@@ -377,7 +377,9 @@ read_NPX_target <- function(filename) {
       dplyr::select(SampleID, Index, OlinkID,
                     UniProt, Assay, MissingFreq,
                     Panel,Panel_Version,PlateID,
-                    QC_Warning,dplyr::matches("Plate_LQL"),
+                    QC_Warning,
+                    dplyr::matches("Plate_LQL"),
+                    dplyr::matches("PlateLQL"),
                     dplyr::matches("LOD"),
                     dplyr::matches("Plate_LOD"),
                     dplyr::matches("PlateLOD"),
